==> hx_components_flutter-1.1.1.tar.gz: lib/src/widgets/hx_text_input.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:hx_components_flutter/src/models/input_types.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';
import 'package:mask_text_input_formatter/mask_text_input_formatter.dart';

class HxTextInput extends StatefulWidget {
  final TextFieldType textFieldType;
  final String label;
  final TextEditingController? controller;
  final Function(String)? onChangedInputFunction;
  final IconData? icon;
  final String? initialValue;
  final String? errorText;
  final VoidCallback? onTap;
  final String? Function(String?)? validator;
  final Function(String)? onFieldSubmitted;
  final bool? isLoading;
  final FocusNode? focusNode;

  const HxTextInput({
    super.key,
    this.controller,
    required this.label,
    this.icon,
    this.errorText,
    this.initialValue,
    this.onChangedInputFunction,
    this.onTap,
    this.validator,
    this.onFieldSubmitted,
    this.isLoading,
    this.focusNode,
  }) : textFieldType = TextFieldType.text;

  const HxTextInput.typed({
    super.key,
    required this.controller,
    required this.label,
    required this.textFieldType,
    this.icon,
    this.errorText,
    this.initialValue,
    this.onChangedInputFunction,
    this.onTap,
    this.validator,
    this.onFieldSubmitted,
    this.isLoading,
    this.focusNode,
  });

  @override
  State<HxTextInput> createState() => _TextInputState();
}

class _TextInputState extends State<HxTextInput> {
  bool _passwordObscure = true;

  TextInputType? keyboardType;

  List<TextInputFormatter>? inputMask;

  MaskTextInputFormatter phoneFormatter = MaskTextInputFormatter(
    mask: '(##) #####-####',
    filter: {
      '#': RegExp('[0-9]')
    },
  );

  MaskTextInputFormatter nameFormatter = MaskTextInputFormatter(
    filter: {
      '#': RegExp('[a-z, A-Z]')
    },
  );

  MaskTextInputFormatter cnhFormatter = MaskTextInputFormatter(
    mask: '###########',
    filter: {
      '#': RegExp('[0-9]')
    },
  );

  MaskTextInputFormatter rgFormatter = MaskTextInputFormatter(
    mask: '##.###.###-#',
    filter: {
      '#': RegExp('[0-9, x, A-Z]')
    },
  );

  MaskTextInputFormatter cpfFormatter = MaskTextInputFormatter(
    mask: '###.###.###-##',
    filter: {
      '#': RegExp('[0-9xX]')
    },
  );

  MaskTextInputFormatter dateFormatter = MaskTextInputFormatter(
    mask: '##/##/####',
    filter: {
      '#': RegExp('[0-9]')
    },
  );

  MaskTextInputFormatter emailFormatter = MaskTextInputFormatter(
    mask: '(##) #####-####',
    filter: {
      '#': RegExp('[a-z, A-Z]')
    },
  );

  MaskTextInputFormatter codigoBarrasFormatter = MaskTextInputFormatter(
    mask: '#####.##### #####.###### #####.###### # ##############',
    filter: {
      '#': RegExp('[0-9]')
    },
  );

  MaskTextInputFormatter comprovanteFormatter = MaskTextInputFormatter(
    mask: '###-####',
    filter: {
      '#': RegExp('[A-Za-z0-9]')
    },
  );

  MaskTextInputFormatter cnpjFormatter = MaskTextInputFormatter(
    mask: '##.###.###/####-##',
    filter: {
      '#': RegExp('[0-9]')
    },
  );

  MaskTextInputFormatter unitFormatter = MaskTextInputFormatter(
    mask: '###############',
    filter: {
      '#': RegExp('[A-Za-z0-9]')
    },
  );

  TextInputType setTextInputType() {
    _passwordObscure = widget.textFieldType == TextFieldType.password && _passwordObscure;
    switch (widget.textFieldType) {
      case TextFieldType.cnh:
        keyboardType = TextInputType.number;
        inputMask = [
          cnhFormatter
        ];
        break;
      case TextFieldType.date:
        keyboardType = TextInputType.datetime;
        inputMask = [
          dateFormatter
        ];
        break;
      case TextFieldType.email:
        keyboardType = TextInputType.emailAddress;
        break;
      case TextFieldType.password:
        keyboardType = TextInputType.visiblePassword;
        break;
      case TextFieldType.rg:
        keyboardType = TextInputType.visiblePassword;
        inputMask = [
          rgFormatter
        ];
        break;
      case TextFieldType.text:
        keyboardType = TextInputType.text;
        inputMask = [
          nameFormatter
        ];
        break;
      case TextFieldType.phone:
        keyboardType = TextInputType.number;
        inputMask = [
          phoneFormatter
        ];
        break;
      case TextFieldType.codigoBarras:
        keyboardType = TextInputType.number;
        inputMask = [
          codigoBarrasFormatter
        ];
        break;
      case TextFieldType.comprovante:
        keyboardType = TextInputType.text;
        inputMask = [
          comprovanteFormatter
        ];
        break;
      case TextFieldType.unit:
        keyboardType = TextInputType.text;
        inputMask = [
          unitFormatter
        ];
        break;
    }
    return TextInputType.text;
  }

  bool validator() {
    if (widget.controller != null) {
      switch (widget.textFieldType) {
        case TextFieldType.cnh:
          return widget.controller!.text.length == 11;
        case TextFieldType.date:
          return widget.controller!.text.length == 10;
        case TextFieldType.email:
          return widget.controller!.text.contains('@');
        case TextFieldType.password:
          return widget.controller!.text.length >= 6;
        case TextFieldType.rg:
          return widget.controller!.text.length == 12;
        case TextFieldType.text:
          return widget.controller!.text.length >= 3;
        case TextFieldType.phone:
          return widget.controller!.text.length == 15;
        case TextFieldType.codigoBarras:
          return widget.controller!.text.length == 48;
        case TextFieldType.comprovante:
          return widget.controller!.text.length == 9;
        case TextFieldType.unit:
          return widget.controller!.text.length == 10;
      }
    }
    return false;
  }

  @override
  void initState() {
    if (widget.controller != null) {
      widget.controller!.text = widget.initialValue ?? '';
    }
    setTextInputType();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        LayoutBuilder(
          builder: (context, constraints) {
            return TextFormField(
              onFieldSubmitted: widget.onFieldSubmitted,
              onTap: widget.onTap,
              controller: widget.controller,
              inputFormatters: inputMask,
              keyboardType: keyboardType,
              obscureText: _passwordObscure,
              validator: widget.validator ??
                  (value) {
                    if (value == null || value.isEmpty) {
                      return widget.errorText ?? '';
                    }
                    return null;
                  },
              onChanged: (value) {
                if (widget.textFieldType == TextFieldType.unit && widget.controller != null) {
                  widget.controller!.value = TextEditingValue(
                    text: value.toUpperCase(),
                    selection: widget.controller!.selection,
                  );
                }

                widget.onChangedInputFunction != null ? widget.onChangedInputFunction!(value) : () {};
              },
              style: const TextStyle(
                fontSize: 16,
              ),
              decoration: InputDecoration(
                labelText: widget.label,
                labelStyle: const TextStyle(
                  fontSize: 16,
                ),
                errorBorder: const UnderlineInputBorder(
                  borderSide: BorderSide(color: kcError),
                ),
                errorStyle: widget.errorText == null ? const TextStyle(height: 0) : const TextStyle(color: kcError),
                prefixIcon: widget.icon != null
                    ? Padding(
                        padding: const EdgeInsets.only(left: 8.0),
                        child: Icon(widget.icon),
                      )
                    : null,
                prefixIconConstraints: const BoxConstraints(
                  minWidth: 40,
                ),
                suffixIcon: widget.textFieldType == TextFieldType.password
                    ? IconButton(
                        splashRadius: 1,
                        icon: Icon(
                          _passwordObscure ? Icons.visibility_off : Icons.visibility,
                        ),
                        onPressed: () {
                          setState(
                            () {
                              _passwordObscure = !_passwordObscure;
                            },
                          );
                        },
                      )
                    : null,
                filled: true,
                fillColor: kcLightGrey,
                isDense: true,
                border: UnderlineInputBorder(
                  borderSide: BorderSide(color: kcSecondaryColor),
                ),
              ),
              focusNode: widget.focusNode,
            );
          },
        ),
        if (widget.isLoading ?? false) const LinearProgressIndicator() else const SizedBox(),
      ],
    );
  }
}

==> hx_components_flutter-1.1.2.tar.gz: lib/src/widgets/hx_text_input.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:hx_components_flutter/src/models/input_types.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';
import 'package:mask_text_input_formatter/mask_text_input_formatter.dart';

class HxTextInput extends StatefulWidget {
  final TextFieldType textFieldType;
  final String label;
  final TextEditingController? controller;
  final Function(String)? onChangedInputFunction;
  final IconData? icon;
  final String? initialValue;
  final String? errorText;
  final VoidCallback? onTap;
  final String? Function(String?)? validator;
  final Function(String)? onFieldSubmitted;
  final bool? isLoading;
  final FocusNode? focusNode;

  /// Mask for unit input input using # as placeholder
  ///
  /// Example: '##########'
  final String? unitMask;

  const HxTextInput({
    super.key,
    this.controller,
    required this.label,
    this.icon,
    this.errorText,
    this.initialValue,
    this.onChangedInputFunction,
    this.onTap,
    this.validator,
    this.onFieldSubmitted,
    this.isLoading,
    this.focusNode,
    this.unitMask,
  }) : textFieldType = TextFieldType.text;

  const HxTextInput.typed({
    super.key,
    required this.controller,
    required this.label,
    required this.textFieldType,
    this.icon,
    this.errorText,
    this.initialValue,
    this.onChangedInputFunction,
    this.onTap,
    this.validator,
    this.onFieldSubmitted,
    this.isLoading,
    this.focusNode,
    this.unitMask,
  });

  @override
  State<HxTextInput> createState() => _TextInputState();
}

class _TextInputState extends State<HxTextInput> {
  bool _passwordObscure = true;

  TextInputType? keyboardType;

  List<TextInputFormatter>? inputMask;

  MaskTextInputFormatter phoneFormatter = MaskTextInputFormatter(
    mask: '(##) #####-####',
    filter: {
      '#': RegExp('[0-9]')
    },
  );

  MaskTextInputFormatter nameFormatter = MaskTextInputFormatter(
    filter: {
      '#': RegExp('[a-z, A-Z]')
    },
  );

  MaskTextInputFormatter cnhFormatter = MaskTextInputFormatter(
    mask: '###########',
    filter: {
      '#': RegExp('[0-9]')
    },
  );

  MaskTextInputFormatter rgFormatter = MaskTextInputFormatter(
    mask: '##.###.###-#',
    filter: {
      '#': RegExp('[0-9, x, A-Z]')
    },
  );

  MaskTextInputFormatter cpfFormatter = MaskTextInputFormatter(
    mask: '###.###.###-##',
    filter: {
      '#': RegExp('[0-9xX]')
    },
  );

  MaskTextInputFormatter dateFormatter = MaskTextInputFormatter(
    mask: '##/##/####',
    filter: {
      '#': RegExp('[0-9]')
    },
  );

  MaskTextInputFormatter emailFormatter = MaskTextInputFormatter(
    mask: '(##) #####-####',
    filter: {
      '#': RegExp('[a-z, A-Z]')
    },
  );

  MaskTextInputFormatter codigoBarrasFormatter = MaskTextInputFormatter(
    mask: '#####.##### #####.###### #####.###### # ##############',
    filter: {
      '#': RegExp('[0-9]')
    },
  );

  MaskTextInputFormatter comprovanteFormatter = MaskTextInputFormatter(
    mask: '###-####',
    filter: {
      '#': RegExp('[A-Za-z0-9]')
    },
  );

  MaskTextInputFormatter cnpjFormatter = MaskTextInputFormatter(
    mask: '##.###.###/####-##',
    filter: {
      '#': RegExp('[0-9]')
    },
  );

  MaskTextInputFormatter getUnitFormatter() {
    return MaskTextInputFormatter(
      mask: widget.unitMask ?? '#############',
      filter: {
        '#': RegExp('[A-Za-z0-9]')
      },
    );
  }

  TextInputType setTextInputType() {
    _passwordObscure = widget.textFieldType == TextFieldType.password && _passwordObscure;
    switch (widget.textFieldType) {
      case TextFieldType.cnh:
        keyboardType = TextInputType.number;
        inputMask = [
          cnhFormatter
        ];
        break;
      case TextFieldType.date:
        keyboardType = TextInputType.datetime;
        inputMask = [
          dateFormatter
        ];
        break;
      case TextFieldType.email:
        keyboardType = TextInputType.emailAddress;
        break;
      case TextFieldType.password:
        keyboardType = TextInputType.visiblePassword;
        break;
      case TextFieldType.rg:
        keyboardType = TextInputType.visiblePassword;
        inputMask = [
          rgFormatter
        ];
        break;
      case TextFieldType.text:
        keyboardType = TextInputType.text;
        inputMask = [
          nameFormatter
        ];
        break;
      case TextFieldType.phone:
        keyboardType = TextInputType.number;
        inputMask = [
          phoneFormatter
        ];
        break;
      case TextFieldType.codigoBarras:
        keyboardType = TextInputType.number;
        inputMask = [
          codigoBarrasFormatter
        ];
        break;
      case TextFieldType.comprovante:
        keyboardType = TextInputType.text;
        inputMask = [
          comprovanteFormatter
        ];
        break;
      case TextFieldType.unit:
        keyboardType = TextInputType.text;
        inputMask = [
          getUnitFormatter()
        ];
        break;
    }
    return TextInputType.text;
  }

  bool validator() {
    if (widget.controller != null) {
      switch (widget.textFieldType) {
        case TextFieldType.cnh:
          return widget.controller!.text.length == 11;
        case TextFieldType.date:
          return widget.controller!.text.length == 10;
        case TextFieldType.email:
          return widget.controller!.text.contains('@');
        case TextFieldType.password:
          return widget.controller!.text.length >= 6;
        case TextFieldType.rg:
          return widget.controller!.text.length == 12;
        case TextFieldType.text:
          return widget.controller!.text.length >= 3;
        case TextFieldType.phone:
          return widget.controller!.text.length == 15;
        case TextFieldType.codigoBarras:
          return widget.controller!.text.length == 48;
        case TextFieldType.comprovante:
          return widget.controller!.text.length == 9;
        case TextFieldType.unit:
          return widget.controller!.text.length == 10;
      }
    }
    return false;
  }

  @override
  void initState() {
    if (widget.controller != null) {
      widget.controller!.text = widget.initialValue ?? '';
    }
    setTextInputType();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        LayoutBuilder(
          builder: (context, constraints) {
            return TextFormField(
              onFieldSubmitted: widget.onFieldSubmitted,
              onTap: widget.onTap,
              controller: widget.controller,
              inputFormatters: inputMask,
              keyboardType: keyboardType,
              obscureText: _passwordObscure,
              validator: widget.validator ??
                  (value) {
                    if (value == null || value.isEmpty) {
                      return widget.errorText ?? '';
                    }
                    return null;
                  },
              onChanged: (value) {
                if (widget.textFieldType == TextFieldType.unit && widget.controller != null) {
                  widget.controller!.value = TextEditingValue(
                    text: value.toUpperCase(),
                    selection: widget.controller!.selection,
                  );
                }

                widget.onChangedInputFunction != null ? widget.onChangedInputFunction!(value) : () {};
              },
              style: const TextStyle(
                fontSize: 16,
              ),
              decoration: InputDecoration(
                labelText: widget.label,
                labelStyle: const TextStyle(
                  fontSize: 16,
                ),
                errorBorder: const UnderlineInputBorder(
                  borderSide: BorderSide(color: kcError),
                ),
                errorStyle: widget.errorText == null ? const TextStyle(height: 0) : const TextStyle(color: kcError),
                prefixIcon: widget.icon != null
                    ? Padding(
                        padding: const EdgeInsets.only(left: 8.0),
                        child: Icon(widget.icon),
                      )
                    : null,
                prefixIconConstraints: const BoxConstraints(
                  minWidth: 40,
                ),
                suffixIcon: widget.textFieldType == TextFieldType.password
                    ? IconButton(
                        splashRadius: 1,
                        icon: Icon(
                          _passwordObscure ? Icons.visibility_off : Icons.visibility,
                        ),
                        onPressed: () {
                          setState(
                            () {
                              _passwordObscure = !_passwordObscure;
                            },
                          );
                        },
                      )
                    : null,
                filled: true,
                fillColor: kcLightGrey,
                isDense: true,
                border: UnderlineInputBorder(
                  borderSide: BorderSide(color: kcSecondaryColor),
                ),
              ),
              focusNode: widget.focusNode,
            );
          },
        ),
        if (widget.isLoading ?? false) const LinearProgressIndicator() else const SizedBox(),
      ],
    );
  }
}
